@@ -1,3 +1,5 @@
+# vi:si:noet:sw=4:sts=4:ts=8
+
 #
 # Erminig-NG (A two-way synchronization tool for Google-Calendar and
 #              "Fremantle-Calendar", the calendar of Maemo 5)
@@ -139,4 +141,7 @@ class Event:
 			return 0
 
 	def get_alarm(self):
-		return self.alarm
+		"""
+		@rtype: str
+		"""
+		return str(self.alarm)
