@@ -1,4 +1,5 @@
 #!/usr/bin/python2.5
+# vi:si:noet:sw=4:sts=4:ts=8
 #
 # Erminig-NG (A two-way synchronization tool for Google-Calendar and
 #              "Fremantle-Calendar", the calendar of Maemo 5)
@@ -116,9 +117,23 @@ def isEventFullDay(date):
 	else:
 		return 0
 
+# iso8601 forms:
+#     YYYY (eg 1997)
+#     YYYY-MM (eg 1997-07)
+#     YYYY-MM-DD (eg 1997-07-16)
+#     YYYY-MM-DDThh:mmTZD (eg 1997-07-16T19:20+01:00) -> 17 or 21 chars
+#     YYYY-MM-DDThh:mm:ssTZD (eg 1997-07-16T19:20:30+01:00) -> 20 or 24 chars
+#     YYYY-MM-DDThh:mm:ss.sTZD (eg 1997-07-16T19:20:30.45+01:00) -> 22 or 26
+# with TZD: Z or +hh:mm or -hh:mm)
+
 def iso8601ToTimestamp(date):
-	if not date[-6] in ('+', '-') and not date.endswith('Z'): 
-		date += 'Z' 
+	"""
+	@type date: str
+	"""
+	# FIXME: Google passes dtstart like 2008-12-10T00:00:00
+	if not date[-6] in ('+', '-') and not date.endswith('Z'):
+		date += 'Z'
+
 	return int(iso8601.parse(date))
 
 def timestampToIso8601(date):
@@ -421,7 +436,12 @@ def getLocalIdFromGoogleId(gid):
 		return None
 
 def updateGoogleEvent(evt, googleid, pid):
-
+	"""
+	@type  evt:      L{Event.Event}
+	@param googleid: name of calendar ?
+	@type  googleid: unicode
+	@type  pid:      int
+	"""
 	# get Googleid of event:
 	gid = getGoogleIdFromLocalId(evt.get_id())
 	if not gid:
